function [logprob]= logpitchprob(selected_chs, selected_peaks, lags, lptable, uftable) 
%
% calculate the log-probability of pitch based on "A multipitch Tracking algorithm for noisy speech" by Mingyang Wu.
%
% kslee@ee.columbia.edu, 6/24/2005
% [2011-05-07] Byung Suk Lee bsl@ee.columbia.edu
%
nchs = length(selected_chs);
nlags = length(lags);
distparm1 = 1.21 - 0.011*[1:nchs]; 

p = zeros(nchs,nlags);

for ch = 1:nchs
    if selected_chs(ch) > 0
        peaks = selected_peaks(ch,selected_peaks(ch,:)>0);
        npeaks = length(peaks);
        local_prob = zeros(npeaks,nlags);
        for npks = 1:npeaks
            local_prob(npks,:) = reshape(lptable(peaks(npks),ch,:),1,nlags);
        end
        p(ch,:) = sum(local_prob);
    else
        % low-freq. channels
        p(ch,:) = uftable(ch,:);
    end
end

logprob = sum(p);
